@@ -2,11 +2,6 @@
 
 package App::WHMCSUtils;
 
-our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
-our $DATE = '2019-11-29'; # DATE
-our $DIST = 'App-WHMCSUtils'; # DIST
-our $VERSION = '0.011'; # VERSION
-
 use 5.010001;
 use strict;
 use warnings;
@@ -20,6 +15,11 @@ use LWP::UserAgent;
 use Path::Tiny;
 use WWW::Mechanize;
 
+our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
+our $DATE = '2021-11-30'; # DATE
+our $DIST = 'App-WHMCSUtils'; # DIST
+our $VERSION = '0.012'; # VERSION
+
 our %SPEC;
 
 $SPEC{':package'} = {
@@ -176,9 +176,9 @@ sub restore_whmcs_client {
             $CWD = $sql_backup_dir;
             my @cmd;
             if ($decompress) {
-                push @cmd, "zcat", $pt->absolute->stringify, "|";
+                push @cmd, "zcat", $pt->absolute->stringify, \"|";
             } else {
-                push @cmd, "cat", $pt->absolute->stringify, "|";
+                push @cmd, "cat", $pt->absolute->stringify, \"|";
             }
             push @cmd, "mysql-sql-dump-extract-tables",
                 "--include-table-pattern", '^(tblclients|tblinvoices|tblinvoiceitems|tblorders)$';
@@ -904,7 +904,7 @@ sub send_verification_emails {
         my $sender_email = $orig_sender_email;
         if ($args{hook_set_sender_email}) {
             unless (ref $args{hook_set_sender_email} eq 'CODE') {
-                $args{hook_set_sender_email} = eval "sub { $args{hook_set_sender_email} }";
+                $args{hook_set_sender_email} = eval "sub { $args{hook_set_sender_email} }"; ## no critic: BuiltinFunctions::ProhibitStringyEval
                 die "Can't compile code in hook_set_sender_email: $@" if $@;
             }
             $sender_email = $args{hook_set_sender_email}->($client_rec, $orig_sender_email);
@@ -936,7 +936,7 @@ App::WHMCSUtils - CLI utilities related to WHMCS
 
 =head1 VERSION
 
-This document describes version 0.011 of App::WHMCSUtils (from Perl distribution App-WHMCSUtils), released on 2019-11-29.
+This document describes version 0.012 of App::WHMCSUtils (from Perl distribution App-WHMCSUtils), released on 2021-11-30.
 
 =head1 FUNCTIONS
 
@@ -945,7 +945,7 @@ This document describes version 0.011 of App::WHMCSUtils (from Perl distribution
 
 Usage:
 
- calc_deferred_revenue(%args) -> [status, msg, payload, meta]
+ calc_deferred_revenue(%args) -> [$status_code, $reason, $payload, \%result_meta]
 
 Deferring revenue is the process of recognizing revenue as you earn it, in
 contrast to as you receive the cash. This is the principle of accrual
@@ -1075,16 +1075,17 @@ Example (in JSON):
 
 =item * B<output_file> => I<filename>
 
+
 =back
 
 Returns an enveloped result (an array).
 
-First element (status) is an integer containing HTTP status code
+First element ($status_code) is an integer containing HTTP-like status code
 (200 means OK, 4xx caller error, 5xx function error). Second element
-(msg) is a string containing error message, or 'OK' if status is
-200. Third element (payload) is optional, the actual result. Fourth
-element (meta) is called result metadata and is optional, a hash
-that contains extra information.
+($reason) is a string containing error message, or something like "OK" if status is
+200. Third element ($payload) is the actual result, but usually not present when enveloped result is an error response ($status_code is not 2xx). Fourth
+element (%result_meta) is called result metadata and is optional, a hash
+that contains extra information, much like how HTTP response headers provide additional metadata.
 
 Return value:  (any)
 
@@ -1094,7 +1095,7 @@ Return value:  (any)
 
 Usage:
 
- restore_whmcs_client(%args) -> [status, msg, payload, meta]
+ restore_whmcs_client(%args) -> [$status_code, $reason, $payload, \%result_meta]
 
 Restore a missing client from SQL database backup.
 
@@ -1128,6 +1129,7 @@ Can accept either C<.sql> or C<.sql.gz>.
 Will be converted first to a directory where the SQL file will be extracted to
 separate files on a per-table basis.
 
+
 =back
 
 Special arguments:
@@ -1136,18 +1138,18 @@ Special arguments:
 
 =item * B<-dry_run> => I<bool>
 
-Pass -dry_run=>1 to enable simulation mode.
+Pass -dry_run=E<gt>1 to enable simulation mode.
 
 =back
 
 Returns an enveloped result (an array).
 
-First element (status) is an integer containing HTTP status code
+First element ($status_code) is an integer containing HTTP-like status code
 (200 means OK, 4xx caller error, 5xx function error). Second element
-(msg) is a string containing error message, or 'OK' if status is
-200. Third element (payload) is optional, the actual result. Fourth
-element (meta) is called result metadata and is optional, a hash
-that contains extra information.
+($reason) is a string containing error message, or something like "OK" if status is
+200. Third element ($payload) is the actual result, but usually not present when enveloped result is an error response ($status_code is not 2xx). Fourth
+element (%result_meta) is called result metadata and is optional, a hash
+that contains extra information, much like how HTTP response headers provide additional metadata.
 
 Return value:  (any)
 
@@ -1157,7 +1159,7 @@ Return value:  (any)
 
 Usage:
 
- send_verification_emails(%args) -> [status, msg, payload, meta]
+ send_verification_emails(%args) -> [$status_code, $reason, $payload, \%result_meta]
 
 Send verification emails for clients who have not had their email verified.
 
@@ -1232,6 +1234,7 @@ It should be without C</admin> part, e.g.:
 
  https://client.mycompany.com/
 
+
 =back
 
 Special arguments:
@@ -1240,18 +1243,18 @@ Special arguments:
 
 =item * B<-dry_run> => I<bool>
 
-Pass -dry_run=>1 to enable simulation mode.
+Pass -dry_run=E<gt>1 to enable simulation mode.
 
 =back
 
 Returns an enveloped result (an array).
 
-First element (status) is an integer containing HTTP status code
+First element ($status_code) is an integer containing HTTP-like status code
 (200 means OK, 4xx caller error, 5xx function error). Second element
-(msg) is a string containing error message, or 'OK' if status is
-200. Third element (payload) is optional, the actual result. Fourth
-element (meta) is called result metadata and is optional, a hash
-that contains extra information.
+($reason) is a string containing error message, or something like "OK" if status is
+200. Third element ($payload) is the actual result, but usually not present when enveloped result is an error response ($status_code is not 2xx). Fourth
+element (%result_meta) is called result metadata and is optional, a hash
+that contains extra information, much like how HTTP response headers provide additional metadata.
 
 Return value:  (any)
 
@@ -1263,6 +1266,42 @@ Please visit the project's homepage at L<https://metacpan.org/release/App-WHMCSU
 
 Source repository is at L<https://github.com/perlancar/perl-App-WHMCSUtils>.
 
+=head1 SEE ALSO
+
+=head1 AUTHOR
+
+perlancar <perlancar@cpan.org>
+
+=head1 CONTRIBUTOR
+
+=for stopwords Steven Haryanto (on pc-office)
+
+Steven Haryanto (on pc-office) <steven@masterweb.com>
+
+=head1 CONTRIBUTING
+
+
+To contribute, you can send patches by email/via RT, or send pull requests on
+GitHub.
+
+Most of the time, you don't need to build the distribution yourself. You can
+simply modify the code, then test via:
+
+ % prove -l
+
+If you want to build the distribution (e.g. to try to install it locally on your
+system), you can install L<Dist::Zilla>,
+L<Dist::Zilla::PluginBundle::Author::PERLANCAR>, and sometimes one or two other
+Dist::Zilla plugin and/or Pod::Weaver::Plugin. Any additional steps required
+beyond that are considered a bug and can be reported to me.
+
+=head1 COPYRIGHT AND LICENSE
+
+This software is copyright (c) 2021, 2019, 2018, 2017 by perlancar <perlancar@cpan.org>.
+
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
+
 =head1 BUGS
 
 Please report any bugs or feature requests on the bugtracker website L<https://rt.cpan.org/Public/Dist/Display.html?Name=App-WHMCSUtils>
@@ -1271,17 +1310,4 @@ When submitting a bug or request, please include a test-file or a
 patch to an existing test-file that illustrates the bug or desired
 feature.
 
-=head1 SEE ALSO
-
-=head1 AUTHOR
-
-perlancar <perlancar@cpan.org>
-
-=head1 COPYRIGHT AND LICENSE
-
-This software is copyright (c) 2019, 2018, 2017 by perlancar@cpan.org.
-
-This is free software; you can redistribute it and/or modify it under
-the same terms as the Perl 5 programming language system itself.
-
 =cut
